@@ -6,15 +6,15 @@
 #endif
 
 constexpr const int one = 1;
-extern "C" void F77_CALL(saxpy)(const int *, const float*, const float *, const int*, float*, const int*);
-extern "C" void F77_CALL(scopy)(const int *, const float*, const int *, float *, const int *);
+// extern "C" void F77_CALL(saxpy)(const int *, const float*, const float *, const int*, float*, const int*);
+// extern "C" void F77_CALL(scopy)(const int *, const float*, const int *, float *, const int *);
 
 /* Note: it'd be faster to take these functions from the 'float' package (which will end up linking
    to BLAS), but it gives too many headaches, especailly in some platforms like windows, and at
    the time of writing, the maintainer of the 'float' package had mostly abandoned it and was
    not replying to PRs fixing linkage issues. If some other package comes out offering single-precision
    BLAS, should be safe to just switch to it instead. */
-void F77_CALL(saxpy)(const int *n, const float *a, const float *x, const int *incx, float *y, const int *incy)
+static inline void F77_CALL(saxpy)(const int *n, const float *a, const float *x, const int *incx, float *y, const int *incy)
 {
     const int n_ = *n;
     const int inc_x = *incx;
@@ -32,7 +32,7 @@ void F77_CALL(saxpy)(const int *n, const float *a, const float *x, const int *in
     }
 }
 
-void F77_CALL(scopy)(const int *n, const float *x, const int *incx, float *y, const int *incy)
+static inline void F77_CALL(scopy)(const int *n, const float *x, const int *incx, float *y, const int *incy)
 {
     for (int ix = 0; ix < *n; ix++) {
         y[ix * (*incy)] = x[ix * (*incx)];
